developerscripttools.DeveloperScript
====================================

.. abjad-lineage:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript

.. autoclass:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.alias
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.argument_parser
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_help
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_usage
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_version
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.long_description
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.process_args
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.program_name
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.scripting_group
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.setup_argument_parser
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.short_description
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.version
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__call__
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__eq__
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__ne__
      ~abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.setup_argument_parser
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__repr__
   :noindex:
